import django_tables2 as tables

from netbox.tables import (
    NetBoxTable,
    ToggleColumn,
    ActionsColumn,
)

from netbox_storage.models import WindowsVolume


class WindowsVolumeBaseTable(NetBoxTable):
    """Base class for tables displaying WindowsVolume"""

    fs = tables.Column(
        linkify=True,
    )
    drive_name = tables.Column(
        linkify=True,
        verbose_name="Drive Name"
    )
    virtual_machine = tables.Column(
        linkify=True
    )


class WindowsVolumeTable(WindowsVolumeBaseTable):
    """Table for displaying WindowsVolume objects."""

    pk = ToggleColumn()

    class Meta(NetBoxTable.Meta):
        model = WindowsVolume
        fields = (
            "pk",
            "drive_name",
            "fs",
            "drives",
            "virtual_machine",
            "description",
        )
        default_columns = (
            "drive_name",
            "fs",
            "description"
        )


class RelatedWindowsVolumeTable(WindowsVolumeBaseTable):
    actions = ActionsColumn(actions=())

    class Meta(NetBoxTable.Meta):
        model = WindowsVolume
        fields = (
            "pk",
            "drive_name",
            "fs",
            "description",
        )
        default_columns = (
            "drive_name",
            "fs",
            "description"
        )




from netbox.views import generic

from netbox_storage.filters import WindowsVolumeFilter
from netbox_storage.forms import (
    WindowsVolumeImportForm,
    WindowsVolumeFilterForm,
    WindowsVolumeForm,
    WindowsVolumeBulkEditForm
)

from netbox_storage.models import WindowsVolume
from netbox_storage.tables import WindowsVolumeTable


class WindowsVolumeListView(generic.ObjectListView):
    queryset = WindowsVolume.objects.all()
    filterset = WindowsVolumeFilter
    filterset_form = WindowsVolumeFilterForm
    table = WindowsVolumeTable


class WindowsVolumeView(generic.ObjectView):
    """Display WindowsVolume details"""

    queryset = WindowsVolume.objects.all()


class WindowsVolumeEditView(generic.ObjectEditView):
    """View for editing a WindowsVolume instance."""

    queryset = WindowsVolume.objects.all()
    form = WindowsVolumeForm
    default_return_url = "plugins:netbox_storage:windowsvolume_list"


class WindowsVolumeDeleteView(generic.ObjectDeleteView):
    queryset = WindowsVolume.objects.all()
    default_return_url = "plugins:netbox_storage:windowsvolume_list"


class WindowsVolumeBulkImportView(generic.BulkImportView):
    queryset = WindowsVolume.objects.all()
    model_form = WindowsVolumeImportForm
    table = WindowsVolumeTable
    default_return_url = "plugins:netbox_storage:windowsvolume_list"


class WindowsVolumeBulkEditView(generic.BulkEditView):
    queryset = WindowsVolume.objects.all()
    filterset = WindowsVolumeFilter
    table = WindowsVolumeTable
    form = WindowsVolumeBulkEditForm


class WindowsVolumeBulkDeleteView(generic.BulkDeleteView):
    queryset = WindowsVolume.objects.all()
    table = WindowsVolumeTable




from netbox.views import generic

from netbox_storage.filters import LinuxVolumeFilter
from netbox_storage.forms import (
    LinuxVolumeImportForm,
    LinuxVolumeFilterForm,
    LinuxVolumeForm,
    LinuxVolumeBulkEditForm
)

from netbox_storage.models import LinuxVolume
from netbox_storage.tables import LinuxVolumeTable


class LinuxVolumeListView(generic.ObjectListView):
    queryset = LinuxVolume.objects.all()
    filterset = LinuxVolumeFilter
    filterset_form = LinuxVolumeFilterForm
    table = LinuxVolumeTable


class LinuxVolumeView(generic.ObjectView):
    """Display LinuxVolume details"""

    queryset = LinuxVolume.objects.all()


class LinuxVolumeEditView(generic.ObjectEditView):
    """View for editing a LinuxVolume instance."""

    queryset = LinuxVolume.objects.all()
    form = LinuxVolumeForm
    default_return_url = "plugins:netbox_storage:linuxvolume_list"


class LinuxVolumeDeleteView(generic.ObjectDeleteView):
    queryset = LinuxVolume.objects.all()
    default_return_url = "plugins:netbox_storage:linuxvolume_list"


class LinuxVolumeBulkImportView(generic.BulkImportView):
    queryset = LinuxVolume.objects.all()
    model_form = LinuxVolumeImportForm
    table = LinuxVolumeTable
    default_return_url = "plugins:netbox_storage:linuxvolume_list"


class LinuxVolumeBulkEditView(generic.BulkEditView):
    queryset = LinuxVolume.objects.all()
    filterset = LinuxVolumeFilter
    table = LinuxVolumeTable
    form = LinuxVolumeBulkEditForm


class LinuxVolumeBulkDeleteView(generic.BulkDeleteView):
    queryset = LinuxVolume.objects.all()
    table = LinuxVolumeTable

